@@ -1,7 +1,4 @@
-# -*- coding: future_fstrings -*-
-#####################################################################
-### Rohde & Schwarz Automation for demonstration use.
-### Purpose: Vector Signal Analyzer Common Functions
+""" Vector Signal Analyzer Common Functions"""
 ### Author:  Martin C Lim
 ### Date:    2018.02.01
 #####################################################################
@@ -26,7 +23,7 @@ class VSA(jaVisa):
         return ACLR
 
     def Get_Mkr_BandACLR(self):
-        for i in range(1,3+1):
+        for i in range(1, 3+1):
             if i == 1:
                 ACLR = f'{self.Get_Mkr_Band(i)[1]:7.3f}'
             else:
@@ -80,9 +77,7 @@ class VSA(jaVisa):
         return rdStr
 
     def Get_IQ_Data(self,sFilename="file.iqw"):
-        ####################################################################
-        ### Get the IQ data and store to IQW file to process in VSE
-        ####################################################################
+        """ IQ data --> IQW file for VSE"""
         self.write("FORM REAL,32")
         self.write("TRAC:IQ:DATA:FORM IQP")
         self.write("TRAC:IQ:DATA?")
@@ -105,7 +100,7 @@ class VSA(jaVisa):
         #   totalbytes = totalbytes + data [i]
         #   i += 1
 
-        iqfile = open (sFilename, "wb")
+        iqfile = open(sFilename, "wb")
         iqfile.write(data[2 + int(digits):])
         iqfile.close()
 
@@ -122,6 +117,7 @@ class VSA(jaVisa):
         return CSVd
 
     def Get_IQ_Data_Ascii2(self):
+        """Return IQ data as CSV string"""
         CSVd = ""
         self.write('FORMAT:DATA ASCII')
         self.write('TRAC:IQ:DATA:FORM IQP')
@@ -134,7 +130,7 @@ class VSA(jaVisa):
         self.write('FORMAT:DATA REAL,32')
         self.write('TRAC:IQ:DATA:FORM IQP')
         self.write('TRAC:IQ:DATA:MEM?')
-        rdStr = self.K2.read_raw()
+        rdStr = self.jav_read_raw()
         numBytes = int(chr(rdStr[1]))                   # Number of Bytes
         numIQ    = int(rdStr[2:2+numBytes])
         IQBytes  = rdStr[(numBytes+2):-1]               # Remove Header
@@ -166,10 +162,10 @@ class VSA(jaVisa):
         return [ValX, ValY]
 
     def Get_Mkr_TimeDomain(self,iNum=1,iWind=1):
-      # self.write(':CALC:MARK%d:FUNC:SUMM:STAT ON'%iNum)
+        # self.write(':CALC:MARK%d:FUNC:SUMM:STAT ON'%iNum)
         #MkrFreq = self.query(':CALC%d:MARK%d:X?'%(iWind,iNum)).strip()
-        MkrPwr  = self.query(':CALC%d:MARK%d:FUNC:SUMM:RMS:RES?'%(iWind,iNum)).strip()
-        return float(MkrPwr)
+        MkrPwr  = self.queryFloat(f':CALC{iWind}:MARK{iNum}:FUNC:SUMM:RMS:RES?')
+        return MkrPwr
 
     def Get_Mkr_XY(self,iNum=1,iWind=1):
         ValX = self.query(':CALC%d:MARK%d:X?'%(iWind,iNum)).strip()
@@ -272,7 +268,7 @@ class VSA(jaVisa):
         self.write('HCOP:IMM')           #Create File
 
     def Get_SweepOpt(self):
-        #AUTO | SPEed | DYN
+        """AUTO | SPEed | DYN"""
         rdStr = self.query(':SENS:SWE:OPT?')
         return rdStr
 
@@ -285,7 +281,7 @@ class VSA(jaVisa):
         return rdStr
 
     def Get_SweepType(self):
-        #AUTO | SWE | FFT
+        """AUTO | SWE | FFT"""
         rdStr = self.query(':SENS:SWE:TYPE?')
         return rdStr
 
@@ -295,8 +291,8 @@ class VSA(jaVisa):
 
     def Get_Trace_Data(self,trace=1):
         self.write('FORM ASCII ')
-        DataY = self.query('TRAC%d:DATA? TRACE1'%trace)
-        DataX = self.query('TRAC%d:DATA:X? TRACE1'%trace)
+        DataY = self.query(f'TRAC{trace}:DATA? TRACE1')
+        DataX = self.query(f'TRAC{trace}:DATA:X? TRACE1')
         return [DataX.split(','),DataY.split(',')]
 
     def Get_Trace_Detector(self,trace=1):
@@ -363,9 +359,9 @@ class VSA(jaVisa):
         self.query(':SENS:ADJ:LEV;*OPC?')
         # self.jav_OPC_Wait(':SENS:ADJ:LEV')
 
-    def Set_Autolevel_Proto(self,sState):
-    ### Used by WLAN; K96.  Please use ADJ:LEV;
-        self.write('CONF:POW:AUTO %s;*WAI'%sState)      #ON|OFF|1|0
+    # def Set_Autolevel_Proto(self,sState):
+    # ### Used by WLAN; K96.  Please use ADJ:LEV;
+    #     self.write('CONF:POW:AUTO %s;*WAI'%sState)      #ON|OFF|1|0
 
     def Set_Autolevel_IFOvld(self):
         ####################################################################
@@ -373,7 +369,7 @@ class VSA(jaVisa):
         # """ Optimise level for Mixer Input => Optimal EVM """
         # """ Optimises for signals using IF gain as well as 1dB steps """
         ####################################################################
-        optmix = 10                            # Optimal mixer level
+        optmix = 10                         # Optimal mixer level
         self.Set_SweepCont(0)
         self.Set_Autolevel()
         level = self.Get_Mkr_TimeDomain()
@@ -393,37 +389,37 @@ class VSA(jaVisa):
         self.Set_AttnMech(rfatt)            #Set Attenuation
 
         reflev = maxmix + rfatt
-        self.Set_RefLevel(reflev)          #Set RefLevel
+        self.Set_RefLevel(reflev)           #Set RefLevel
 
-        ifovl = self.Get_Ovld_Stat()      #Check Overload
-        print ("Inital: Ovl:%d Attn:%d RfLvl:%d"%(ifovl,rfatt,reflev))
+        ifovl = self.Get_Ovld_Stat()        #Check Overload
+        print("Inital: Ovl:%d Attn:%d RfLvl:%d"%(ifovl,rfatt,reflev))
 
         # """ Optimising for attenuation """
         while ifovl != 0:
-            print ("ATloop: Ovl:%d Attn:%d RfLvl:%d"%(ifovl,rfatt,reflev))
+            print(f"Atnloop: Ovl:{ifovl} Attn:{rfatt} RfLvl:{reflev}")
             rfatt = rfatt + 1
             self.Set_AttnMech(rfatt)
 
             reflev = maxmix + rfatt
             self.Set_RefLevel(reflev)
-
-            # """ Check if there is IF Overload """
-            ifovl = self.Get_Ovld_Stat()
+            ifovl = self.Get_Ovld_Stat()    #Check Overload
+            if reflev > 30:
+                break
 
         # """ Optimising for reference level """
         while reflev > (-20 - gain) and ifovl == 0:
-            print ("RefLop: Ovl:%d Attn:%d RfLvl:%d"%(ifovl,rfatt,reflev))
+            print(f"Refloop: Ovl:{ifovl} Attn:{rfatt} RfLvl:{reflev}")
             reflev = reflev - 1
             self.Set_RefLevel(reflev)
-
-            # """ Check if there is IF Overload """
-            ifovl = self.Get_Ovld_Stat()
+            ifovl = self.Get_Ovld_Stat()    #Check Overload
+            if reflev > 30:
+                break
 
         # """ Final check for IF Overload """
         if ifovl != 0:
             reflev = reflev + 1
             self.Set_RefLevel(reflev)
-        print ("Final : Ovl:%d Attn:%d RfLvl:%d"%(ifovl,rfatt,reflev))
+        print(f"Final : Ovl:{ifovl} Attn:{rfatt} RfLvl:{reflev}")
 
     def Set_Autolevel_IQIF(self,tables):
         VSAL.Optimise_FSx_Level(self,tables)
@@ -432,7 +428,7 @@ class VSA(jaVisa):
     ### FSW CCDF
     #####################################################################
     def Set_CCDF(self,sState):
-        self.write(f'CALC:STAT:CCDF {sState} ;*WAI') #ON|OFF|1|0
+        self.write(f'CALC:STAT:CCDF {sState} ;*WAI')        #ON|OFF|1|0
 
     def Set_CCDF_BW(self,BW):
         self.Set_ResBW(BW)
@@ -469,8 +465,9 @@ class VSA(jaVisa):
         self.write('SENS:CORR:FRES:Input1:USER:SLIS1:SEL "%s"'%sFile)
 
     def Set_EQ_State(self,sState):
-        FSW.write('SENS:CORR:FRES:Input1:USER:PRES')
-        self.write('SENS:CORR:FRES:Input1:USER:STATe %s'%sState)
+        """ON | OFF"""
+        self.write('SENS:CORR:FRES:Input1:USER:PRES')
+        self.write(f'SENS:CORR:FRES:Input1:USER:STATe {sState}')
 
     def Set_Freq(self,fFreq):
         """Hz"""
@@ -572,7 +569,7 @@ class VSA(jaVisa):
         self.Set_SweepTime(fSwpTime)
 
     def Set_IQ_WideBandMax(self,fFreq):
-        """Hz"""
+        """80 160 320 500 1200 MHz"""
         self.write('TRAC:IQ:WBAN:STAT ON')                  #Wideband reduction activated
         self.write('TRAC:IQ:WBAN:MBW %f; *WAI'%fFreq)
 
@@ -608,6 +605,7 @@ class VSA(jaVisa):
         self.write(f':CALC{iWind}:DELT{iNum}:FUNC:BPOW:MODE RPOW')
 
     def Set_Mkr_BandSetRef(self):
+        """Autolevel w/ BandMarkers"""
         self.Set_AttnAuto()
         self.Set_SweepCont(0)
         self.Set_InitImm()                                   # Take Sweep
@@ -663,6 +661,10 @@ class VSA(jaVisa):
         else:
             self.Set_Preamp('OFF')
 
+    def Set_Ref_Source(self,sSource):
+        """INT EXT E10 E100 E1000 EAUT"""
+        self.write(f'ROSC:SOUR {sSource}')
+
     def Set_RefLevel(self,fReflevel):
         self.write('DISP:WIND:TRAC:Y:SCAL:RLEV %fdBm'%fReflevel)
 
@@ -738,15 +740,16 @@ class VSA(jaVisa):
         self.write('TRIG:SEQ:SOUR %s'%sDetect)
 
     def Set_Trig2_Dir(self,sDir):
+        """OUT | INP """
         if sDir == 'OUT':
             self.write('OUTP:TRIG2:DIR OUTP')
         else:
             self.write('OUTP:TRIG2:DIR INP')
 
     def Set_Trig2_OutType(self,sDir):
-        #DEV : Device
-        #TARM: Trigger Armed
-        #UDEF: User Defined
+        """DEV : Device
+        TARM: Trigger Armed
+        UDEF: User Defined"""
         self.write(f'OUTP:TRIG2:OTYP {sDir}')
 
     def Set_VidBW(self,fFreq):
@@ -755,18 +758,13 @@ class VSA(jaVisa):
         else:
             self.write(':SENS:BAND:VID %f'%fFreq)
 
-    def Set_YIG(self,sState):
-        """ON|OFF|1|0"""
-        self.write('INP:FILT:YIG:STAT %s;*WAI'%sState)
-
-
 #####################################################################
 ### Run if Main
 #####################################################################
 if __name__ == "__main__":
     ### this won't be run when imported
-    FSW = VSA().jav_Open("192.168.1.109")
+    FSW = VSA().jav_Open("192.168.58.109")
     # print(FSW.Get_Param(1,0,1,1,1))
-    FSW.Set_Channel('iqasdf')
+    asdf = FSW.Get_Mkr_Freq()
     FSW.jav_ClrErr()
     del FSW
