@@ -1,12 +1,6 @@
-# -*- coding: future_fstrings -*-
-###############################################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Purpose: Vector Signal Analyzer 5GNR Functions
-### Author : Martin C Lim
-### Date   : 2018.04.03
-###############################################################################
-from rssd.VSA.Common import VSA                 #pylint: disable=E0611,E0401
+"""Vector Signal Analyzer 5GNR Functions"""
+#pylint: disable=E0611,E0401
+from rssd.VSA.Common import VSA
 
 class VSA(VSA):                                 #pylint: disable=E0102
     """ Rohde & Schwarz Vector Signal Analyzer 5GNR Object """
@@ -209,7 +203,7 @@ class VSA(VSA):                                 #pylint: disable=E0102
             EVMPhyS = self.Get_5GNR_EVM_PhysSig()
             outStr  = f"{Crest:6.3f},{Power:6.3f},{EVMAll:.2f},{EVMPhyC:.2f},{EVMPhyS:.2f}"
         else:
-            outStr  = 'K144_Cres,K144Pwr,5GEVM_All,EVM_PhyCh,EVM_PhySig'
+            outStr  = 'K144_Cres,K144Pwr,5GEVM_All,EVM_PhyCh(PxSCH),EVM_PhySig(DMRS)'
         return outStr
 
     def Get_5GNR_FreqRange(self):
@@ -244,7 +238,8 @@ class VSA(VSA):                                 #pylint: disable=E0102
         return rdStr
 
     def Get_5GNR_TM_Cat(self):
-        rdStr = self.query(f'MMEM:LOAD:TMOD:CC{self.cc}:CAT?').split(',')
+        rdStr = 'Command not available'
+        # rdStr = self.query(f'MMEM:LOAD:TMOD:CC{self.cc}:CAT?').split(',')
         return rdStr
 
     def Get_5GNR_TransPrecoding(self):
@@ -260,6 +255,7 @@ class VSA(VSA):                                 #pylint: disable=E0102
     #####################################################################
     def Init_5GNR(self):
         self.Set_Channel('NR5G')
+        self.write(f'CONF:NR5G:MEAS EVM')
 
     def Init_5GNR_Meas(self,sMeas):
         """ EVM; ESPectrum; ACLR; TAER"""
@@ -326,8 +322,11 @@ class VSA(VSA):                                 #pylint: disable=E0102
             print('Get_5GNR_BWP_Ch_DMRS_SeqGenSeed Method?')
 
     def Set_5GNR_BWP_Ch_Modulation(self,sMod):
-        # QPSK; QAM16; QAM64; QAM256; PITB
-        self.write(f':CONF:NR5G:{self.sdir}:FRAM1:BWP0:SLOT0:ALL0:MOD {sMod}')
+        """QPSK; QAM16; QAM64; QAM256; PITB"""
+        if self.sdir == 'DL':
+            self.write(f':CONF:NR5G:{self.sdir}:CC{self.cc}:FRAM1:BWP0:SLOT0:ALL0:CW:MOD {sMod}')
+        else:
+            self.write(f':CONF:NR5G:{self.sdir}:CC{self.cc}:FRAM1:BWP0:SLOT0:ALL0:MOD {sMod}')
 
     def Set_5GNR_BWP_Ch_ResBlock(self,iRB):
         ### RB = (CHBw * 0.95) / (SubSp * 12)
@@ -351,7 +350,16 @@ class VSA(VSA):                                 #pylint: disable=E0102
     def Set_5GNR_BWP_ResBlockOffset(self,iRBO):
         self.write(f':CONF:NR5G:{self.sdir}:CC{self.cc}:FRAM1:BWP0:RBOF {iRBO}')
 
+    def Set_5GNR_BWP_Ch_SymbNum(self, symb):
+        """Set BWP Ch Symbol Offset"""
+        self.write(f':CONF:NR5G:{self.sdir}:CC{self.cc}:FRAM1:BWP0:SLOT0:ALL0:SCO {symb}')
+
+    def Set_5GNR_BWP_Ch_SymbOff(self, symb):
+        """Set BWP Ch Symbol Offset"""
+        self.query(f':CONF:NR5G:{self.sdir}:CC{self.cc}:FRAM1:BWP0:SLOT0:ALL0:SOFF {symb}')
+
     def Set_5GNR_BWP_SubSpace(self,iSubSp):
+        """15 30 60 120"""
         self.write(f':CONF:NR5G:{self.sdir}:CC{self.cc}:FRAM1:BWP0:SSP SS{iSubSp}')
 
     def Set_5GNR_CC_Num(self,iNumCC):
@@ -372,7 +380,7 @@ class VSA(VSA):                                 #pylint: disable=E0102
         self.write(f'CONF:NR5G:{self.sdir}:CC{self.cc}:PLC:CID {iCellID}')
 
     def Set_5GNR_ChannelBW(self,iBW):
-        ### 5;10;15;20;25;30;40;50;60;70;80;90;100;200;400
+        """5;10;15;20;25;30;40;50;60;70;80;90;100;200;400"""
         self.write(f':CONF:NR5G:{self.sdir}:CC{self.cc}:BW BW{iBW}')
 
     def Set_5GNR_Direction(self,sDirection):
@@ -416,9 +424,6 @@ class VSA(VSA):                                 #pylint: disable=E0102
         else:
             print('Set_5GNR_FreqRange invalid parameter')
 
-    def Set_5GNR_Parameters(self,sDir):
-        self.Set_5GNR_Direction(sDir)
-
     def Set_5GNR_PhaseCompensate(self,state):
         """ 'ON' | 'OFF' """
         if (state == "ON") or (state == 1):
@@ -449,6 +454,7 @@ class VSA(VSA):                                 #pylint: disable=E0102
         self.write(f':SENS:NR5G:FRAM:SLOT {dSubFrame}')
 
     def Set_5GNR_TM(self, file):
+        """NR-FR1-TM1_1__FDD_15MHz_30kHz"""
         self.query(f'MMEM:LOAD:TMOD:CC{self.cc} "{file}";*OPC?')
 
     def Set_5GNR_TransPrecoding(self,sState):
