@@ -1,12 +1,5 @@
-# -*- coding: future_fstrings -*-
-#####################################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Purpose: Vector Signal Generator Common Functions
-### Author : Martin C Lim
-### Date   : 2018.02.01
-### Requird: python -m pip install pyvisa
-#####################################################################
+"""Vector Signal Generator Common Functions
+"""
 from time           import sleep
 from rssd.yaVISA    import jaVisa        #pylint: disable=E0611,E0401
 
@@ -14,10 +7,11 @@ class VSG(jaVisa):
     """ Rohde & Schwarz Vector Signal Generator Object """
     def __init__(self):
         super(VSG,self).__init__()     #Python2/3
-        self.Model = "SMW"
+        self.Model  = "SMW"
+        self.NRP    = 2
 
     #####################################################################
-     ### SMW Get
+    ### SMW Get
     #####################################################################
     def Get_ArbClockFreq(self):
         SCPI = self.queryFloat('SOUR:BB:ARB:CLOC?')
@@ -29,8 +23,8 @@ class VSG(jaVisa):
 
     def Get_ArbTime(self):
         Fs = self.Get_ArbClockFreq()
-        Points = self.query('BB:ARB:WAV:POIN?').strip()
-        WvTime = int(Points)/int(Fs)
+        Points = self.queryInt('BB:ARB:WAV:POIN?')
+        WvTime = Points/int(Fs)
         return WvTime
 
     def Get_ArbInfo(self):
@@ -57,10 +51,12 @@ class VSG(jaVisa):
         return rdInt
 
     def Get_NRPPower(self,NRP=2):
-        self.write(':INIT%d:POW:CONT 1'%(NRP))
-        self.write('SENS%d:UNIT DBM'%(NRP))
-        self.write('SENS%d:TYPE?'%(NRP))
-        SCPI = self.queryFloat(':READ%d:POW?'%(NRP))
+        self.write(f':INIT{NRP}:POW:CONT 1')
+        self.write(f'SENS{NRP}:UNIT DBM')
+        self.query(f'SENS{NRP}:TYPE?')
+        SCPI = self.queryFloat(f':READ{NRP}:POW?')
+        if SCPI < -198: SCPI = self.queryFloat(f':READ{NRP}:POW?')
+        if SCPI < -198: SCPI = self.queryFloat(f':READ{NRP}:POW?')
         return SCPI
 
     def Get_OS_Dir(self):
@@ -78,7 +74,6 @@ class VSG(jaVisa):
                 outList.append(rdStr[i][0])
         return outList
 
-
     def Get_PowerPEP(self,RF=1):
         SCPI = self.queryFloat('SOUR%d:POW:PEP?'%RF)
         return SCPI
@@ -119,12 +114,12 @@ class VSG(jaVisa):
     def Init_Wideband(self):
         self.write('SOUR:POW:ATT:DIG 3')            #Set Digital Attenuation
         self.write('POW:ALC:STATE AUTO')            #Turn ALC ON|OFF|OFFT|AUTO|
-        self.write('SOUR:POW:ALC:DAMP AUTO')      #Turn Driver AMP ON|OFF|AUTO
-        self.write('SOUR:BB:IQG DB8')                #Baseband IQ gain
+        self.write('SOUR:POW:ALC:DAMP AUTO')        #Turn Driver AMP ON|OFF|AUTO
+        self.write('SOUR:BB:IQG DB8')               #Baseband IQ gain
 
         ## Not so critical
         self.write('SOUR:AWGN:STAT 0')              #Turn AWGN off (default)
-        self.write('BBIN:STAT OFF')                  #Turn BB Input off(default)
+        self.write('BBIN:STAT OFF')                 #Turn BB Input off(default)
 
     #####################################################################
     ### SMW Settting Methods
@@ -231,6 +226,17 @@ class VSG(jaVisa):
         """RunMode: LIVE LEARned """
         self.write(f'SOUR:LIST:RMOD {sMode}')
 
+    def Set_NRP_Freq(self, Freq):
+        """Frequency if NRP in USER mode"""
+        self.write(f':SENS{self.NRP}:POW:FREQ {Freq}')
+
+    def Set_NRP_Mode(self, sMode):
+        """USER | A"""
+        if sMode == "USER":
+            self.write(f':SENS{self.NRP}:POW:SOUR USER')
+        else:
+            self.write(f':SENS{self.NRP}:POW:SOUR A')
+
     def Set_OS_Dir(self,sDir):
         self.write(f'MMEMory:CDIRectory "/var/user/{sDir}"')
 
@@ -252,12 +258,37 @@ class VSG(jaVisa):
     def Set_PhaseDelta(self,fPhase):
         self.write(':SOUR1:PHASE %d'%(fPhase))
 
+    def Set_PM_State(self, State):
+        if State in (1, '1', 'ON'):
+            self.write(':SOUR1:PM1:STAT ON')
+        else:
+            self.write(':SOUR1:PM1:STAT OFF')
+
+    def Set_PM_Source(self, Source):
+        """LF1 LF2 EXT1 EXT2 NOIS INT EXT"""
+        self.write(f':SOUR1:PM1:SOUR {Source}')
+
+    def Set_Ref_Source(self,sSource):
+        """Ext Int"""
+        self.write(f':SOUR1:ROSC:SOUR {sSource}')
+
+    def Set_Ref_Freq(self,sFreq):
+        """10MHZ 100MHZ 1GHz"""
+        self.write(f':SOUR1:ROSC:EXT:FREQ {sFreq}')
+
+    def Set_Ref_SyncBW(self,sBW):
+        """WIDE NARR"""
+        self.write(f':SOUR1:ROSC:EXT:SBAN {sBW}')    #SMW WIDE(Vary less)|NARR(varys more) bandwidth
+
     def Set_RFPwr(self,fPow):
         self.write('SOUR:POW %f'%fPow)
 
     def Set_RFState(self,sState):
         ''' 0 1 '''
-        self.query('OUTP %s;*OPC?'%sState)
+        if sState in (1,'1','ON'):
+            self.query('OUTP 1;*OPC?')
+        if sState in (0,'0','OFF'):
+            self.query('OUTP 0;*OPC?')
 
     def Set_Setting(self,sSettingFile):
         """*.savrcltxt SettingFile"""
