@@ -1,12 +1,5 @@
-# -*- coding: future_fstrings -*-
-#####################################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Purpose: Vector Signal Generator Fading Methods
-### Author : Martin C Lim
-### Date   : 2020.03.09
-### Requird: python -m pip install rssd
-#####################################################################
+"""Vector Signal Generator Fading Methods
+"""
 from rssd.VSG.Common import VSG             #pylint: disable=E0611,E0401
 
 class VSG(VSG):                             #pylint: disable=E0102
@@ -57,7 +50,6 @@ class VSG(VSG):                             #pylint: disable=E0102
         self.K2.timeout = 5000
 
 
-
 #####################################################################
 ### Run if Main
 #####################################################################
