@@ -1,16 +1,13 @@
-# -*- coding: future_fstrings -*-
-#####################################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Purpose: Vector Signal Generator LTE Functions
-### Author : Martin C Lim
-### Date   : 2019.03.05
-### Requird: python -m pip install rssd
-### Options: K55  LTE Rel  8 Initial Release
-###          K84  LTE Rel  9 Pos Ref Signal
-###          K85  LTE Rel 10 Carrier aggregation
-###          K112 LTE Rel 11
+"""
+Vector Signal Generator LTE Functions
+### Options: K55  LTE Rel  8: LTE 20MHz 64QAM 
+###          K84  LTE Rel  9: MBMS & MBSFN generation
+###          K85  LTE Rel 10: CA; Enhanced SC-FDMA; UL MIMO
+###          K112 LTE Rel 11: TDD Config9&7
+###          K113 LTE Rel 12: DL 256QAM; TDD/FDD Mixed CA
+###          K119 LTE Rel 13/14/15: UL 256QAM; LAA
 #####################################################################
+"""
 from rssd.VSG.Common import VSG     #pylint: disable=E0611,E0401
 
 class VSG(VSG):                     #pylint: disable=E0102
@@ -78,9 +75,8 @@ class VSG(VSG):                     #pylint: disable=E0102
         else:
             self.write(':SOUR1:BB:EUTR:STAT 0')
 
-
     def Set_LTE_CC(self,iCC):
-        self.write(''%())
+        # self.write(''%())
         if iCC > 0:
             self.write(f':SOUR:BB:EUTR:{self.ldir}:CA:STAT 1')
 
