@@ -1,12 +1,4 @@
-# -*- coding: future_fstrings -*-
-#####################################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Purpose: Vector Signal Generator 5G NR Functions
-### Author : Martin C Lim
-### Date   : 2018.02.01
-### Requird: python -m pip install rssd
-#####################################################################
+"""Vector Signal Generator 5G NR Functions"""
 from rssd.VSG.Common import VSG             #pylint: disable=E0611,E0401
 
 class VSG(VSG):                             #pylint: disable=E0102
@@ -62,7 +54,7 @@ class VSG(VSG):                             #pylint: disable=E0102
 
     def Get_5GNR_BWP_Ch_DMRS_MSymbLen(self):
         if self.sdir == 'DL':
-            rdStr = self.query(f':SOUR:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:PDSCH:DMRS:LENG?')  #MMM
+            rdStr = self.query(f':SOUR:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:PDSCH:DMRS:LENG?')      #MMM
         else:
             rdStr = self.query(f':SOUR:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:PUSC:DMRS:LENG?')
         return rdStr
@@ -77,7 +69,7 @@ class VSG(VSG):                             #pylint: disable=E0102
 
     def Get_5GNR_BWP_Ch_DMRS_SeqGenMeth(self):
         if self.sdir == 'DL':
-            rdStr = self.query(f':SOUR:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:PDSC:DMRS:SEQG?') #MMM
+            rdStr = self.query(f':SOUR:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:PDSC:DMRS:SEQG?')   #MMM
         else:
             rdStr = self.query(f':SOUR:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:PUSC:DMRS:SEQG?')
         # rdStr = "<TBD>"
@@ -252,7 +244,7 @@ class VSG(VSG):                             #pylint: disable=E0102
         # SC-FDMA or DFT-S-OFDM
         # 5GNR--> User/BWP --> UL BWP Config --> PUSCH --> TP
         # rdStr = self.query(f':SOUR1:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL0:TPST?')
-        rdStr = self.query(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:UL:BWP0:PUSC:TPST?') #4.50
+        rdStr = self.query(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:UL:BWP0:PUSC:TPST?')   #4.50
         return rdStr
 
     #####################################################################
@@ -261,11 +253,14 @@ class VSG(VSG):                             #pylint: disable=E0102
     def Set_5GNR_BBState(self,iEnable):
         """ON OFF"""
         if (iEnable == 1) or (iEnable == 'ON'):
-            self.jav_OPC_Wait(':SOUR1:BB:NR5G:STAT 1')
+            self.jav_Wait(':SOUR1:BB:NR5G:STAT 1')
 #            self.query(f'*OPC?')          # Wait for calculation
         else:
             self.write(f':SOUR1:BB:NR5G:STAT 0')
 
+    def Set_5GNR_BWP_CellID(self, iCellID):
+        self.write(f':SOUR1:BB:NR5G:NODE:CELL{self.cc}:CELL {iCellID}')
+
     def Set_5GNR_BWP_Ch_Modulation(self,sMod):
         self.write(f':SOUR1:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:MOD {sMod}')
 
@@ -293,7 +288,7 @@ class VSG(VSG):                             #pylint: disable=E0102
 
     def Set_5GNR_BWP_ResBlockMax(self):
         ### RB = (CHBw * 0.95) / (SubSp * 12)
-        MaxRB =  20
+        MaxRB = 20
         rdStr = self.query(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:{self.sdir}:BWP0:RBN {MaxRB}')
         return rdStr
 
@@ -327,6 +322,10 @@ class VSG(VSG):                             #pylint: disable=E0102
         self.write(f':SOUR1:BB:NR5G:NODE:CELL{self.cc}:TXBW:RES')
         self.write(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:{self.sdir}:BWP0:SCSP N{iSubSp}')
 
+    def Set_5GNR_BWP_Users(self,iUsers):
+        """Number of users"""
+        self.write(f':SOUR1:BB:NR5G:UBWP:NUS {iUsers}')
+
     def Set_5GNR_CC_Num(self,iCC):
         """ iCC, 1 start """
         self.cc = iCC - 1
@@ -336,7 +335,6 @@ class VSG(VSG):                             #pylint: disable=E0102
         """ freq, Hz """
         self.write(f':SOUR1:BB:NR5G:NODE:CARM:DFR:ROW{self.cc} {Freq}')
 
-
     def Set_5GNR_ChannelBW(self,iBW):
         """ BW in MHz
          5GNR-->NODE-->Carriers-->Channel BW"""
@@ -387,9 +385,9 @@ class VSG(VSG):                             #pylint: disable=E0102
     def Set_5GNR_PhaseCompensate(self,state):
         """ 'ON' | 'OFF' """
         if (state == "ON") or (state == 1):
-            self.write(f':SOUR:BB:NR5G:NODE:RFPH:STAT ON')
+            self.write(f':SOUR:BB:NR5G:NODE:RFPH:MODE AUTO')
         else:
-            self.write(f':SOUR:BB:NR5G:NODE:RFPH:STAT OFF')
+            self.write(f':SOUR:BB:NR5G:NODE:RFPH:MODE OFF')
 
     def Set_5GNR_PhaseCompensate_Freq(self,Freq):
         self.write(f':SOUR:BB:NR5G:NODE:CELL{self.cc}:PCFR {Freq}')
@@ -408,10 +406,10 @@ class VSG(VSG):                             #pylint: disable=E0102
         5GNR--> User/BWP --> UL BWP Config --> PUSCH --> TP  """
         if sState == 'ON':
             # self.write(f':SOUR1:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL0:TPST ON') #4.30SP2?
-            self.write(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:UL:BWP0:PUSC:TPST ON') #4.50
+            self.write(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:UL:BWP0:PUSC:TPST ON')     #4.50
         else:
             # self.write(f':SOUR1:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL0:TPST OFF') #4.30SP2?
-            self.write(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:UL:BWP0:PUSC:TPST OFF') #4.50
+            self.write(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:UL:BWP0:PUSC:TPST OFF')    #4.50
 
     def Set_5GNR_Setting_Load(self, sName):
         self.query(f':SOUR:BB:NR5G:SETT:LOAD "/var/user/{sName}";*OPC?')
