@@ -54,7 +54,7 @@ VSA.Set_Trace_AvgCount(Avg)
 VSA.Set_Trace_Detector('RMS')
 VSA.Set_SweepOpt(SweMode)
 VSA.Set_SweepType(SweType)
-VSA.Set_YIG('OFF')
+VSA.Set_In_YIG('OFF')
 # VSA.Set_Trig1_Source('Ext')
 
 ################################################################################
@@ -108,7 +108,7 @@ for i in range(Repeat):
         TotTime     = f'{ALTime:2,.6f},{TestTime:2,.6f},{TotTime:2,.6f}'
         MeasData    = ACLR
         OutStr      = f'{LoopParam},{TotTime},{AmpParam},{SwpParam},{TrcParam},{SysParam},{MeasData}'
-        OFile.write (OutStr)
+        OFile.write(OutStr)
 
 # VSAL.WriteLevellingTables(Freq, table)
 SuiteTime = timeit.default_timer() - tick0
