@@ -14,7 +14,7 @@ LTE_Dir     = 'UL'
 waveparam   =[[20,100],
               [20,66]]
 subFArry    = [1]
-modArry     = ['QPSK', 'QAM64'] #QPSK; QAM16; QAM64; QAM256
+modArry     = ['QPSK', 'QAM64']     #QPSK; QAM16; QAM64; QAM256
 numMeas     = 1
 AutoLvl     = 0                #0:AutoRef 1:AutoLevel
 SCFDMA      = 'OFF'
@@ -49,7 +49,7 @@ LTE.FSW.Set_LTE_EVMUnit('DB')
 LTE.FSW.Set_Trig1_Source('EXT')
 LTE.FSW.Set_SweepCont(0)
 LTE.FSW.Init_CCDF()
-LTE.FSW.Set_YIG(0)
+LTE.FSW.Set_In_YIG(0)
 LTE.FSW.Set_CCDF_BW(120e6)
 LTE.FSW.Set_CCDF_Samples(2e6)
 LTE.FSW.Set_Trig1_Source('IMM')
@@ -92,7 +92,7 @@ for i in range(numMeas):                                        #Loop: Measureme
                         d = datetime.now() - tick       #Measurement only
                         t = datetime.now() - tickA      #Autolevel + Measurement
                         OutStr = f'{i},{LTE.FSW.Model},{freq},{EVM},{LTE.LTE_ChBW},{LTE.LTE_TF},{LTE.LTE_RB},{LTE.LTE_Mod},{pwr:3d},{subFram},{Attn},{AutoLvl},{ALTime.seconds:3d}.{ALTime.microseconds:06d},cf:{ccdf},{d.seconds:3d}.{d.microseconds:06d},{t.seconds:3d}.{t.microseconds:06d}'
-                        OFile.write (OutStr)
+                        OFile.write(OutStr)
 
 ##########################################################
 ### Cleanup Automation
