@@ -1,19 +1,14 @@
-###############################################################################
-### Rohde & Schwarz Automation for demonstration use.
-### Title  : 5G NR Carrier Aggregation Example
-### Author : mclim
-### Date   : 2020.03.12
-###
+"""5G NR FSW/SMW Carrier Aggregation Setup Example"""
 ###############################################################################
 ### User Entry
 ###############################################################################
-SMW_IP      = '192.168.1.114'
-FSW_IP      = '192.168.1.109'
-FreqArry    = [10e9, 20e9, 24e9, 28e9, 39e9]
-pwrArry     = range(-40,10,1)                                       #Power Array
+SMW_IP      = '192.168.58.114'
+FSW_IP      = '192.168.58.109'
+FreqArry    = range(9500000000, 12900000000, 50000000)
+pwrArry     = [-5]                              #Power Array
 NR_Dir      = 'UL'
-waveparam   = [[100,120,66,'64QAM']]                                 #ChBW, SubSp, RB, Mod
-NumCC       = 1
+waveparam   = [[100,120,66,'QPSK']]                #ChBW, SubSp, RB, Mod
+NumCC       = 14
 CCSpace     = 99.96e6
 CCStart     = (1 - NumCC) * (CCSpace/2)
 numMeas     = 1
@@ -23,8 +18,6 @@ DFT_S_OFDM  = 'ON'
 ### Code Overhead: Import and create objects
 ###############################################################################
 import timeit
-# import ctypes                                       #MessageBoxW
-# from datetime                   import datetime     #pylint: disable=E0611,E0401
 from rssd.FileIO                import FileIO       #pylint: disable=E0611,E0401
 from rssd.VST.NR5G_K144         import VST          #pylint: disable=E0611,E0401
 OFile = FileIO().makeFile(__file__)
@@ -56,7 +49,7 @@ NR5G.FSW.Set_5GNR_Direction(NR_Dir)
 NR5G.FSW.Set_SweepCont(0)
 NR5G.FSW.Set_5GNR_FreqRange(2)
 NR5G.FSW.Set_5GNR_CC_Num(NumCC)
-NR5G.FSW.Set_5GNR_SubFrameCount(1)
+NR5G.FSW.Set_5GNR_SubFrameCount(10)
 NR5G.FSW.Set_SweepTime(10.1e-3)
 NR5G.FSW.Set_5GNR_Result_View('ALL')
 
@@ -75,7 +68,6 @@ for i in range(numMeas):                                            #LOOP: Measu
             for CC in range(NumCC):
                 NR5G.FSW.cc = CC+1
                 NR5G.FSW.Set_5GNR_CC_Offset(CC+1,CC*CCSpace)
-            #ctypes.windll.user32.MessageBoxW(0, "Verify", "Please Verify Waveform", 1)
             for pwr in pwrArry:                                     #LOOP: Power
                 tick = timeit.default_timer()                       #Tick Begin meas
                 NR5G.SMW.Set_RFPwr(pwr)
@@ -103,7 +95,7 @@ for i in range(numMeas):                                            #LOOP: Measu
                     EVM         = NR5G.FSW.Get_5GNR_Params_EVM()
                     TimeParam   = f'{ALTime:2,.3f},{TestTime:2,.3f},{TotTime:2,.3f}'
                     OutStr      = f'{LoopParam},{NR5GParam},{AttnParam},{EVM},{TimeParam}'
-                    OFile.write (OutStr)
+                    OFile.write(OutStr)
 
 ###############################################################################
 ### Cleanup Automation
