@@ -21,7 +21,7 @@ import os
 import re
 import math
 import time
-# import array                            # dataConvert
+# import array                          # dataConvert
 import struct
 from datetime import datetime           # writeXml, writeWv
 import tarfile                          # readIqTar, writeIqTar
@@ -30,7 +30,7 @@ import xml.etree.ElementTree as ET      # readIqTar
 class IQ(object):
     """ Util IQ Converting Object """
     def __init__(self):
-        self.iqData = [complex(1,1)]                #Complex IQ Data
+        self.iqData = [complex(1,1)]    #Complex IQ Data
         self.iiqqList = []
         self.iqiqList = []
         self.NumberOfSamples = 0
@@ -42,7 +42,7 @@ class IQ(object):
             print("Expecting IQIQIQ order, input vector has odd number of samples!")
             return
         self.NumberOfSamples = len(iqiq) // 2
-        self.iqData = [ complex(iqiq[2*n], iqiq[2*n+1]) for n in range(self.NumberOfSamples)]
+        self.iqData = [complex(iqiq[2*n], iqiq[2*n+1]) for n in range(self.NumberOfSamples)]
 
     def __iiqq2complex__(self, iiqq):
         """Returns a complex list of I/Q samples from a single list containing IIIQQQ values"""
@@ -50,13 +50,13 @@ class IQ(object):
             print("Expecting IIIQQQ order, input vector has odd number of samples!")
             return
         self.NumberOfSamples = len(iiqq) // 2
-        self.iqData = [ complex(iiqq[n], iiqq[n+self.NumberOfSamples]) for n in range(self.NumberOfSamples)]
+        self.iqData = [complex(iiqq[n], iiqq[n+self.NumberOfSamples]) for n in range(self.NumberOfSamples)]
 
     def __complex2iqiq__(self):
         """Returns a list of I/Q samples from a complex list.
         iqiqlist = __complex2iqiq__(complexList)"""
         f= lambda iq,i: iq.real if i==0 else iq.imag
-        self.iqiqList = [ f(iq,i) for iq in self.iqData for i in range(2)]
+        self.iqiqList = [f(iq,i) for iq in self.iqData for i in range(2)]
 
         return self.iqiqList
 
@@ -67,7 +67,7 @@ class IQ(object):
     #     self.iiqqList.append([ iq.imag for iq in self.iqData])
     #     return self.iiqqList
 
-    def writeIqw(self, FileName):               # Verified 2020.0115
+    def writeIqw(self, FileName):                                               # Verified 2020.0115
         """writes an IQW file (file of binary floats).
         self.iqData can be a list of complex or list of floats.
         Note: IIIQQQ is a deprecated format, don't use it for new files.
@@ -82,11 +82,11 @@ class IQ(object):
             file.write(struct.pack("f"*len(self.iqiqList),*self.iqiqList))
             file.close()
         except:
-            print("File (" + FileName +") write error!" )
+            print("File (" + FileName +") write error!")
             return 0
         return self.NumberOfSamples
 
-    def readIqw(self, FileName, iqiq = True):                                  # Verified 2020.0115
+    def readIqw(self, FileName, iqiq = True):                                   # Verified 2020.0115
         """Reads an IQW (iiqq or iqiq) file--> self.__iXXq2complex__ --> self.iqData
          - If iqiq is True, samples are read pairwise (IQIQIQ)
          - else, samples are read, i first then q (IIIQQQ)
@@ -124,13 +124,10 @@ class IQ(object):
             power.append(abs(self.iqiqList[2*n]**2 + self.iqiqList[2*n+1]**2))
         scaling = math.sqrt(max(power))
 
-        # normalize to magnitude 1
-        self.iqiqList = [iq / scaling for iq in self.iqiqList]
-        #calculate rms in dB (below full scale)
-        rms = math.sqrt(sum(power)/self.NumberOfSamples)/scaling
-        rms = abs(20*math.log10(rms))
-        # Convert to int16
-        self.iqiqList = [math.floor(iq * 32767 +.5) for iq in self.iqiqList]
+        self.iqiqList = [iq / scaling for iq in self.iqiqList]                  # normalize to magnitude 1
+        rms = math.sqrt(sum(power)/self.NumberOfSamples)/scaling                # calculate rms in dB (below full scale)
+        rms = abs(20*math.log10(rms))                                           # Convert to dB
+        self.iqiqList = [math.floor(iq * 32767 +.5) for iq in self.iqiqList]    # Convert to int16
 
         try:
             file = open(FileName, "wb")
@@ -151,11 +148,11 @@ class IQ(object):
             file.write("}".encode("ASCII"))
             file.close()
         except:
-            print("File (" + FileName +") write error!" )
+            print("File (" + FileName +") write error!")
             return 0
         return self.NumberOfSamples
 
-    def readWv(self,FileName):                  # Verified 2020.0115
+    def readWv(self,FileName):                                                          # Verified 2020.0115
         """Reads a WV file --> self.__iqiq2complex__ --> self.iqData"""
         try:
             file = open(FileName, "rb")
@@ -185,26 +182,26 @@ class IQ(object):
         res = re.search("CLOCK[ ]*:[ ]*(?P<SamplingRate>[0-9]*)",tags)
         self.fSamplingRate = float(res.group("SamplingRate"))
         data = list(struct.unpack("h"*self.NumberOfSamples*2, data[binaryStart:-1]))    #MMM data: IQ arry
-        data = list(map( lambda x: x/32767.0, data ))                                   #MMM consumes a lot of time
+        data = list(map(lambda x: x/32767.0, data))                                   #MMM consumes a lot of time
         self.__iqiq2complex__(data)
 
     def writeXml(self, filenameiqw, filenamexml):                                       # Verified  2020.0115
         """Function to write the xml part of the iq.tar"""
-        xmlfile = open (filenamexml, "w")
+        xmlfile = open(filenamexml, "w")
         xmlfile.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n")
         xmlfile.write("<?xml-stylesheet type=\"text/xsl\" href=\"open_IqTar_xml_file_in_web_browser.xslt\"?>\n")
         xmlfile.write("<RS_IQ_TAR_FileFormat fileFormatVersion=\"2\" xsi:noNamespaceSchemaLocation=\"http://www.rohde-schwarz.com/file/RsIqTar.xsd\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\">\n")
-        xmlfile.write("<Name>Python iq.tar writer (self.iqData.py)</Name>\n")       #Optional
-        xmlfile.write("<Comment>RS WaveForm, TheAE-RA</Comment>\n")                 #Optional
+        xmlfile.write("<Name>Python iq.tar writer (self.iqData.py)</Name>\n")           #Optional
+        xmlfile.write("<Comment>RS WaveForm, TheAE-RA</Comment>\n")                     #Optional
         xmlfile.write("<DateTime>"+ datetime.now(None).isoformat() +"</DateTime>\n")
         xmlfile.write("<Samples>" + str(self.NumberOfSamples) + "</Samples>\n")
         xmlfile.write("<Clock unit=\"Hz\">" + str(self.fSamplingRate) + "</Clock>\n")
         xmlfile.write("<Format>complex</Format>\n")
         xmlfile.write("<DataType>float32</DataType>\n")
-        xmlfile.write("<ScalingFactor unit=\"V\">1</ScalingFactor>\n")              #Optional
-        xmlfile.write("<NumberOfChannels>1</NumberOfChannels>\n")                   #Optional
+        xmlfile.write("<ScalingFactor unit=\"V\">1</ScalingFactor>\n")                  #Optional
+        xmlfile.write("<NumberOfChannels>1</NumberOfChannels>\n")                       #Optional
         xmlfile.write("<DataFilename>" + filenameiqw+ "</DataFilename>\n")
-        # xmlfile.write("<UserData></UserData>\n")                                  #Optional
+        # xmlfile.write("<UserData></UserData>\n")                                      #Optional
         xmlfile.write("</RS_IQ_TAR_FileFormat>\n")
         xmlfile.close()
         return 1
@@ -232,7 +229,7 @@ class IQ(object):
             os.remove(os.path.join(path, binaryfile))
             os.remove(os.path.join(path, xmlfilename))
         except:
-            print("IqTar (" + FileName +") write error!" )
+            print("IqTar (" + FileName +") write error!")
             return 0
 
     def readIqTar(self,FileName):               # Verified 2020.0115
@@ -264,12 +261,11 @@ class IQ(object):
             self.readIqw(binaryfilename)
             os.remove(binaryfilename)
         except:
-            print("IqTar (" + FileName +") read error!" )
+            print("IqTar (" + FileName +") read error!")
 
         self.iqData = [sample * scaling for sample in self.iqData]                      #Apply scaling factor
 
-
-    def main(self):
+    def main(self):     #pragma: no cover
         #for testing only
         filename = "C:\\Users\\lim_m\\ownCloud\\ATE\\AA_Code\\DSP_python\\DSP_python\\SampleWv\\CW_10tones_32MHz_100usec.iq.tar"
 
@@ -285,22 +281,21 @@ class IQ(object):
 
         start = time.time()
         self.writeIqTar(filename + '.iq.tar')
-        self.writeWv(   filename + '.wv')
-        self.writeIqw(  filename + '.iqw')
+        self.writeWv(filename + '.wv')
+        self.writeIqw(filename + '.iqw')
         duration = time.time() - start
         speed = self.NumberOfSamples/1e6/duration
         print("Total: %d samples in %2.2f ms. writeSpeed: %f MSamples/s"%(self.NumberOfSamples,duration*1e3,speed))
 
-def dataConvert():
+def dataConvert():                          #pragma: no cover
     ''' binary to float32 conversion '''
     # numpy.frombuffer dtype=float32()
     sampledata = b'\x0E\x78\x94\xB7'
     print('Data %s %d'%(sampledata,len(sampledata)))
-    print("Float=",struct.unpack("<f",sampledata)) #Little Endian
-    print("Float=",struct.unpack("<f",sampledata)) #Little Endian
-    # print("Float=",array.frombytes(sampledata)) #Little Endian
+    print("Float=",struct.unpack("<f",sampledata))  #Little Endian
+    print("Float=",struct.unpack("<f",sampledata))  #Little Endian
+    # print("Float=",array.frombytes(sampledata))   #Little Endian
 
 if __name__ == "__main__":
-    # execute only if run as a script
     # IQ().main()
     dataConvert()
