@@ -1,11 +1,6 @@
+"""rssd.test.examples"""
+
 from __future__ import print_function
-#coding: future_fstrings
-###############################################################################
-### Rohde & Schwarz SCPI Driver Software Test
-### Purpose: rssd.test.examples
-###############################################################################
-### Code Start
-###############################################################################
 import unittest
 import rssd.test.yaVISA
 import rssd.test.FileIO
@@ -37,4 +32,3 @@ if __name__ == '__main__':
     # unittest.main()     #Run w/o test names
     suite = unittest.TestLoader().loadTestsFromTestCase(TestGeneral)
     unittest.TextTestRunner(verbosity=2).run(suite)
-    
\ No newline at end of file
