@@ -1,15 +1,5 @@
-# # -*- coding: future_fstrings -*-
-###############################################################################
-### Purpose: rssd.VSA.ADemod_K7 test
-###              _   ___        __  _____         _
-###             | | | \ \      / / |_   _|__  ___| |_
-###             | |_| |\ \ /\ / /    | |/ _ \/ __| __|
-###             |  _  | \ V  V /     | |  __/\__ \ |_
-###             |_| |_|  \_/\_/      |_|\___||___/\__|
-###             Please connect instrument prior 2 test
-###############################################################################
-### User Entry
-###############################################################################
+"""rssd.VSA.ADemod_K7 test
+"""
 host = '192.168.1.109'                              #Get local machine name
 
 ###############################################################################
@@ -40,9 +30,20 @@ class TestGeneral(unittest.TestCase):
         getVal = self.FSW.Get_Adem_dbw()
         if self.FSW.connected: self.assertEqual(getVal, 3e6)
 
+    def test_FSW_ADemod_PM(self):
+        self.FSW.Set_Freq(28e9)                          # RF Freq
+        self.FSW.Set_Adem_dbw(200e3)                # Demod BW
+        self.FSW.Set_Adem_Coupling('AC')            # Coupling
+        self.FSW.Set_Adem_PM_Unit('DEG')            # Units
+        self.FSW.Set_Adem_PM_Scale(4)               # Y Scaling
+        self.FSW.Set_Adem_PM_RefPos(50)             # Phase Reference Position
+        self.FSW.Set_Adem_PM_RefVal(1)              # Phase Reference Value
+        self.FSW.Set_In_YIG('ON')                        # YIG ON
+
 ###############################################################################
 ### </Test>
 ###############################################################################
 if __name__ == '__main__':
+    #coverage run -a -m unittest -b -v test_HW_VSA_ADemod
     suite = unittest.TestLoader().loadTestsFromTestCase(TestGeneral)
     unittest.TextTestRunner(verbosity=2).run(suite)
