@@ -1,15 +1,5 @@
-# # -*- coding: future_fstrings -*-
-# ###############################################################################
-### Purpose: rssd.FSW.common_CCDF test
-###              _   ___        __  _____         _
-###             | | | \ \      / / |_   _|__  ___| |_
-###             | |_| |\ \ /\ / /    | |/ _ \/ __| __|
-###             |  _  | \ V  V /     | |  __/\__ \ |_
-###             |_| |_|  \_/\_/      |_|\___||___/\__|
-###             Please connect instrument prior 2 test
-###############################################################################
-### User Entry
-###############################################################################
+"""rssd.FSW.common_CCDF test
+"""
 host = '192.168.1.109'                              #Get local machine name
 
 ###############################################################################
@@ -42,6 +32,6 @@ class TestGeneral(unittest.TestCase):
 ### </Test>
 ###############################################################################
 if __name__ == '__main__':
-    # unittest.main()
+    # coverage run -a -m unittest -b -v test_HW_VSA_Common_CCDF
     suite = unittest.TestLoader().loadTestsFromTestCase(TestGeneral)
     unittest.TextTestRunner(verbosity=2).run(suite)
