@@ -1,15 +1,5 @@
-# # -*- coding: future_fstrings -*-
-###############################################################################
-### Purpose: rssd.VSA.Common_IQ test
-###              _   ___        __  _____         _
-###             | | | \ \      / / |_   _|__  ___| |_
-###             | |_| |\ \ /\ / /    | |/ _ \/ __| __|
-###             |  _  | \ V  V /     | |  __/\__ \ |_
-###             |_| |_|  \_/\_/      |_|\___||___/\__|
-###             Please connect instrument prior 2 test
-###############################################################################
-### User Entry
-###############################################################################
+"""rssd.VSA.Common_IQ test
+"""
 host = '192.168.1.109'                              #Get local machine name
 
 ###############################################################################
@@ -40,12 +30,13 @@ class TestGeneral(unittest.TestCase):
         getVal = self.FSW.Get_IQ_SamplingRate()
 
     def test_FSW_Get_IQData(self):
-        self.FSW.Set_IQ_RecLength(10)
+        self.FSW.Set_IQ_RecLength(100)
         self.FSW.Set_SweepCont(0)
-        if self.FSW.connected: getVal = self.FSW.Get_IQ_Data()
-        # getVal = self.FSW.Get_IQ_Data_Ascii()
-        if self.FSW.connected: getVal = self.FSW.Get_IQ_Data_Ascii2()
-        if self.FSW.connected: getVal = self.FSW.Get_IQ_Data_Bin()
+        getVal = self.FSW.Get_IQ_Data()
+        getVal = self.FSW.Get_IQ_Data_Ascii(10)         # Get 10IQ at a time
+        # if self.FSW.connected == 1: getVal = self.FSW.Get_IQ_Data_Ascii(5)
+        getVal = self.FSW.Get_IQ_Data_Ascii2()
+        if self.FSW.connected == 1: getVal = self.FSW.Get_IQ_Data_Bin()
 
     def test_FSW_Set_IQ_ALCR(self):
         self.FSW.Set_IQ_ACLR(9e6,10e6)
@@ -58,6 +49,7 @@ class TestGeneral(unittest.TestCase):
         self.FSW.Set_IQ_Adv_WindowLenth(101)
         self.FSW.Set_IQ_Adv_FFTLenth(4096+1)
         self.FSW.Set_IQ_Adv_Window('P5')
+        self.FSW.Set_IQ_WideBandMax(80e6)
 
     def test_FSW_Set_IQSpectrum(self):
         self.FSW.Set_IQ_SpectrumWindow()
@@ -66,6 +58,6 @@ class TestGeneral(unittest.TestCase):
 ### </Test>
 ###############################################################################
 if __name__ == '__main__':
-    # unittest.main()
+    # coverage run -a -m unittest -b -v test_HW_VSA_Common_IQ
     suite = unittest.TestLoader().loadTestsFromTestCase(TestGeneral)
     unittest.TextTestRunner(verbosity=2).run(suite)
